.. _contributing:

============================
Contributing to SymPy
============================

This section discusses the necessary steps and guidelines required to contribute to the SymPy project. The TOC has links to the detailed development process.

**Content**

.. toctree::
   :maxdepth: 2

   dev-setup.rst
   dependencies.md
   build-docs.rst
   debug.rst
   docstring.rst
   documentation-style-guide.rst
   make-a-contribution.rst
   deprecations.md
